[dragonegg] r182242 - In gcc-4.8, execute_free_datastructures was inlined into its user and removed.

Duncan Sands baldrick at free.fr
Mon May 20 01:57:20 PDT 2013


Author: baldrick
Date: Mon May 20 03:57:20 2013
New Revision: 182242

URL: http://llvm.org/viewvc/llvm-project?rev=182242&view=rev
Log:
In gcc-4.8, execute_free_datastructures was inlined into its user and removed.
Do the same here.

Modified:
    dragonegg/trunk/src/Backend.cpp

Modified: dragonegg/trunk/src/Backend.cpp
URL: http://llvm.org/viewvc/llvm-project/dragonegg/trunk/src/Backend.cpp?rev=182242&r1=182241&r2=182242&view=diff
==============================================================================
--- dragonegg/trunk/src/Backend.cpp (original)
+++ dragonegg/trunk/src/Backend.cpp Mon May 20 03:57:20 2013
@@ -1676,8 +1676,15 @@ static unsigned int rtl_emit_function(vo
     emit_current_function();
   }
 
   // Free any data structures.
   execute_free_datastructures();
+#else
+  free_dominance_info(CDI_DOMINATORS);
+  free_dominance_info(CDI_POST_DOMINATORS);
+  // And get rid of annotations we no longer need.
+  delete_tree_cfg_annotations();
+#endif
 
   // Finally, we have written out this function!
   TREE_ASM_WRITTEN(current_function_decl) = 1;
@@ -1676,8 +1676,15 @@ static unsigned int rtl_emit_function(vo
   }
 
-  // Free any data structures.
+  // Free tree-ssa data structures.
+#if (GCC_MINOR < 8)
   execute_free_datastructures();





More information about the llvm-commits mailing list